@@ -1,9 +1,8 @@
 from collections import namedtuple
 
 import tensorflow as tf
-from tokenizers import BertWordPieceTokenizer
-from transformers_keras.dataset_utils import AbstractDataset
-from transformers_keras.tokenizers.char_tokenizer import BertCharTokenizer
+from transformers_keras.common.abc_dataset import AbstractDataset
+from transformers_keras.common.char_tokenizer import BertCharTokenizer
 
 from .tokenizer import TokenClassificationLabelTokenizer
 
@@ -16,26 +15,22 @@ class TokenClassificationDataset(AbstractDataset):
     """Dataset for token classification."""
 
     @classmethod
-    def _build_dataset(
+    def _filter(cls, dataset, max_sequence_length=512, **kwargs):
+        dataset = dataset.filter(lambda a, b, c, y: tf.size(a) <= max_sequence_length)
+        return dataset
+
+    @classmethod
+    def _bucket_padding(
         cls,
         dataset,
-        batch_size=64,
-        repeat=None,
-        max_sequence_length=512,
+        batch_size=32,
+        pad_id=0,
         bucket_boundaries=[50, 100, 150, 200, 250, 300, 350, 400, 450, 500],
         bucket_batch_sizes=None,
-        buffer_size=1000000,
-        seed=None,
-        reshuffle_each_iteration=True,
-        pad_id=0,
-        auto_shard_policy=None,
         drop_remainder=False,
         **kwargs
     ):
-        dataset = dataset.filter(lambda a, b, c, y: tf.size(a) <= max_sequence_length)
-        if repeat is not None:
-            dataset = dataset.repeat(repeat)
-        dataset = dataset.shuffle(buffer_size=buffer_size, seed=seed, reshuffle_each_iteration=reshuffle_each_iteration)
+        pad_id = tf.constant(pad_id, dtype=tf.int32)
         # fmt: off
         dataset = cls._bucketing(
             dataset,
@@ -50,8 +45,33 @@ class TokenClassificationDataset(AbstractDataset):
             **kwargs,
         )
         # fmt: on
-        dataset = cls._to_dict(dataset)
-        dataset = cls._auto_shard(dataset, auto_shard_policy=auto_shard_policy)
+        return dataset
+
+    @classmethod
+    def _batch_padding(cls, dataset, batch_size=32, pad_id=0, drop_remainder=False, **kwargs):
+        pad_id = tf.constant(pad_id, dtype=tf.int32)
+        # fmt: off
+        dataset = dataset.padded_batch(
+            batch_size,
+            padded_shapes=([None, ], [None, ], [None, ], [None, ]),
+            padding_values=(pad_id, pad_id, pad_id, pad_id),
+            drop_remainder=drop_remainder,
+        )
+        # fmt: on
+        return dataset
+
+    @classmethod
+    def _fixed_padding(cls, dataset, batch_size=32, pad_id=0, max_sequence_length=512, drop_remainder=False, **kwargs):
+        pad_id = tf.constant(pad_id, dtype=tf.int32)
+        maxlen = tf.constant(max_sequence_length, dtype=tf.int32)
+        # fmt: off
+        dataset = dataset.padded_batch(
+            batch_size,
+            padded_shapes=([maxlen, ], [maxlen, ], [maxlen, ], [maxlen, ]),
+            padding_values=(pad_id, pad_id, pad_id, pad_id),
+            drop_remainder=drop_remainder,
+        )
+        # fmt: on
         return dataset
 
     @classmethod
@@ -75,7 +95,7 @@ class TokenClassificationDataset(AbstractDataset):
         return dataset
 
     @classmethod
-    def _to_dict(cls, dataset):
+    def _to_dict(cls, dataset, **kwargs):
         dataset = dataset.map(
             lambda a, b, c, y: ({"input_ids": a, "segment_ids": b, "attention_mask": c}, y),
             num_parallel_calls=cls.AUTOTUNE,
